@@ -55,14 +55,14 @@ class BroadcastCursor(object):
     def __iter__(self):
         return self
 
-    def next(self):
+    def __next__(self):
         while True:
             try:
                 msg = next(self._cursor)
-            except pymongo.errors.OperationFailure, e:
+            except pymongo.errors.OperationFailure as exc:
                 # In some cases tailed cursor can become invalid
                 # and have to be reinitalized
-                if 'not valid at server' in e.message:
+                if 'not valid at server' in exc.message:
                     self.purge()
 
                     continue
@@ -74,6 +74,7 @@ class BroadcastCursor(object):
         self._offset += 1
 
         return msg
+    next = __next__
 
 
 class Channel(virtual.Channel):
