@@ -255,10 +255,9 @@ class MultiChannelPoller(object):
         self._channels.discard(channel)
 
     def _on_connection_disconnect(self, connection):
-        try:
-            self.poller.unregister(connection._sock)
-        except AttributeError:
-            pass
+        sock = getattr(connection, '_sock', None)
+        if sock is not None:
+            self.poller.unregister(sock)
 
     def _register(self, channel, client, type):
         if (channel, client, type) in self._chan_to_sock:
